@@ -296,6 +296,12 @@ fn s2n_config_get_client_auth_type () {
     assert!(!ptr.is_null());
 }
 
+#[test]
+fn s2n_config_get_ctx () {
+    let ptr = crate::s2n_config_get_ctx as *const ();
+    assert!(!ptr.is_null());
+}
+
 #[test]
 fn s2n_config_new () {
     let ptr = crate::s2n_config_new as *const ();
@@ -392,6 +398,12 @@ fn s2n_config_set_ct_support_level () {
     assert!(!ptr.is_null());
 }
 
+#[test]
+fn s2n_config_set_ctx () {
+    let ptr = crate::s2n_config_set_ctx as *const ();
+    assert!(!ptr.is_null());
+}
+
 #[test]
 fn s2n_config_set_early_data_cb () {
     let ptr = crate::s2n_config_set_early_data_cb as *const ();
